export default {
    "index": 27,
    "lineNumber": 1,
    "column": 28,
    "message": "Cannot use 'await' as identifier inside an async function"
}
